Learn R Programming

CARLIT (version 1.0)

CARLIT-package: Ecological Quality Ratios Calculation and Plot

Description

Functions to calculate and plot ecological quality ratios (EQR) as specified by Ballesteros et al. 2007.

Arguments

Details

Package:
CARLIT
Type:
Package
Version:
1.0
Date:
2015-03-17
License:
GPL-2
The function carlit() caclulates EQR values for each site of a dataset. If saved in an object, results can then be plotted with the function barplotEQR(object name).

References

Ballesteros E., Torras X., Pinedo S., Garcia M., Mangialajo L., de Torres M. (2007) A new methodology based on littoral community cartography dominated by macroalgae for the implementation of the European Water Framework Directive. Marine Pollution Bulletin 55: 171-180.

Examples

Run this code
data(Community_data)
data(Sensitivity_list)
data(EQR_reference)
Results <- carlit(Community_data, Sensitivity_list, EQR_reference)
Results
barplotEQR(Results)

Run the code above in your browser using DataLab