X
A data frame with 5 columns: site (names of the survey sites), coastal morphology (acronyms or words describing the morphology of that stretch of coastline), naturality (a text column that assumes either 'Natural' or 'Artificial', or 'nr' in case this distinction is not necessary or relevant in that specific case), length of stretch of coastline, macoralgal community.
EQR_r
A data frame with four columns: an ID column with progressive numbers, coastal morphology (same values as the 'coastal morphology' column of X), naturality (same values as the 'naturality' column of X), EQR reference values for each combination of coastal morphology and naturality (numeric).